# Scientific Filesystem (SCI-F)

![docs/img/logo/scif-logo.png](docs/img/logo/scif-logo.png)

[![asciicast](https://asciinema.org/a/156490.png)](https://asciinema.org/a/156490?speed=2)

The The Scientific Filesystem is an organizational format for scientific software and metadata. Our goals are centered around  **consistency**, **transparency**, **programmatic accessibility**, and **modularity**. [Read about](http://containers-ftw.org/SCI-F/) the format and please [contribute](https://github.com/vsoch/scif/issues)!

## What is this?
This module will provide tools for generating and interacting with scientific filesystems, optimized for use on a host or inside a container.  The library is currently under heavy development, and it will be announced when the beta is ready. Stay tuned! 

## License

This code is licensed under the Affero GPL, version 3.0 or later [LICENSE](LICENSE).
